Learn R Programming

shinyHugePlot (version 0.3.0)

max_aggregator: Aggregation using local maximum (absolute) values.

Description

Divide the data into small data ranges and find the maximum (absolute) value of each. It may be useful for the waveform data.

Arguments

Format

An R6::R6Class object

Super class

shinyHugePlot::aggregator -> max_aggregator

Methods

Inherited methods


Method new()

Constructor of the Aggregator.

Usage

max_aggregator$new(..., interleave_gaps, coef_gap, NA_position, use_abs = TRUE)

Arguments

interleave_gaps, coef_gap, NA_position, ...

Arguments pass to the constructor of aggregator object.

use_abs

Logical. If TRUE, the absolute value is used.


Method clone()

The objects of this class are cloneable with this method.

Usage

max_aggregator$clone(deep = FALSE)

Arguments

deep

Whether to make a deep clone.

Examples

Run this code
data(noise_fluct)
agg <- max_aggregator$new(interleave_gaps = TRUE)
d_agg <- agg$aggregate(noise_fluct$time, noise_fluct$f500, 1000)
plotly::plot_ly(x = d_agg$x, y = d_agg$y, type = "scatter", mode = "lines")

Run the code above in your browser using DataLab