Learn R Programming

shinyHugePlot (version 0.3.0)

min_max_aggregator: Aggregation using local minimum and maximum values.

Description

Divide the data into small data ranges and find the maximum and minimum values of each. Note that many samples may be replaced with NA, if interleave_gaps = TRUE and the original data is increased or decreased monotonically. Use min_max_ovlp_aggregator instead in that case. n_out must be even number.

Arguments

Format

An R6::R6Class object

Super class

shinyHugePlot::aggregator -> min_max_aggregator

Methods

Inherited methods


Method new()

Constructor of the Aggregator.

Usage

min_max_aggregator$new(..., interleave_gaps, coef_gap, NA_position)

Arguments

interleave_gaps, coef_gap, NA_position, ...

Arguments pass to the constructor of aggregator object.


Method clone()

The objects of this class are cloneable with this method.

Usage

min_max_aggregator$clone(deep = FALSE)

Arguments

deep

Whether to make a deep clone.

Examples

Run this code
data(noise_fluct)
agg <- min_max_aggregator$new(interleave_gaps = TRUE)
d_agg <- agg$aggregate(noise_fluct$time, noise_fluct$f500, 1000)
plotly::plot_ly(x = d_agg$x, y = d_agg$y, type = "scatter", mode = "lines")

Run the code above in your browser using DataLab