Learn R Programming

shinyHugePlot (version 0.3.0)

rng_aggregator: Aggregation that returns ranges of the data.

Description

A super class for describing aggregator that returns x, y, ylwr and yupr values based on given x and y data.

Arguments

Value

List of which elements represent the ranges. If there are no NAs, the length of the list is 1; multiple lists are obtained if there are NAs. Each element of list has x and y values that surround the range of values.

Format

An R6::R6Class object

Super class

shinyHugePlot::aggregator -> rng_aggregator

Methods

Inherited methods


Method new()

Constructor of the Aggregator.

Usage

rng_aggregator$new(interleave_gaps, coef_gap, NA_position, ...)

Arguments

interleave_gaps, coef_gap, NA_position, ...

Arguments pass to the constructor of aggregator object.


Method as_plotly_range()

Compute a plotly trace to illustrate the range of the data.

Usage

rng_aggregator$as_plotly_range(x, y, ylwr, yupr, opacity = 0.5)

Arguments

x, y, ylwr, yupr

Outputs of the sub class of rng_aggregator.

opacity

Numeric, optional. Opacity of the range fill. By default, 0.5.


Method as_range()

Compute x, ylwr and yupr from a plotly trace made by self$as_plotly_range.

Usage

rng_aggregator$as_range(prng)

Arguments

prng

List that represents range values, which must contains x, y. Note that the list may be an element of a list generated by self$as_plotly_range.


Method clone()

The objects of this class are cloneable with this method.

Usage

rng_aggregator$clone(deep = FALSE)

Arguments

deep

Whether to make a deep clone.