A super class for describing aggregator that returns x, y,
ylwr and yupr values based on given x and y data.
List of which elements represent the ranges.
If there are no NAs, the length of the list is 1;
multiple lists are obtained if there are NAs.
Each element of list has x and y values that surround
the range of values.
An R6::R6Class object
shinyHugePlot::aggregator -> rng_aggregator
new()Constructor of the Aggregator.
rng_aggregator$new(interleave_gaps, coef_gap, NA_position, ...)interleave_gaps, coef_gap, NA_position, ...Arguments pass to the constructor of aggregator object.
as_plotly_range()Compute a plotly trace to illustrate the range of the data.
rng_aggregator$as_plotly_range(x, y, ylwr, yupr, opacity = 0.5)x, y, ylwr, yuprOutputs of the sub class of rng_aggregator.
opacityNumeric, optional. Opacity of the range fill. By default, 0.5.
as_range()Compute x, ylwr and yupr from a plotly trace
made by self$as_plotly_range.
rng_aggregator$as_range(prng)prngList that represents range values, which
must contains x, y.
Note that the list may be an element of a list generated by
self$as_plotly_range.
clone()The objects of this class are cloneable with this method.
rng_aggregator$clone(deep = FALSE)deepWhether to make a deep clone.